USCA1 Opinions List

Date of Issuance | Click for Opinion | Click for DocketSheet | Short Title/District
--- | --- | --- | ---
1993/05/25 | 92-1836.01A | 92-1836 | Perez-Perez v. Popular U.S. District Court of Puerto Rico
1993/05/25 | 92-1983.01A | 92-1983 | Oropallo v. U.S.A U.S. District Court for the District of New Hampshire
1993/05/25 | 92-2169.01A | 92-2169 | Rui v. INS U.S. Tax Court, Washington, D.C.
1993/05/25 | 92-2169.01A | 93-1294 | Rui v. INS U.S. Tax Court, Washington, D.C.
1993/05/25 | 92-2409.01A | 92-2409 | Mooney v. United States Dept. U.S. District Court for the District of New Hampshire
1993/05/26 | 92-1897.01A | 92-1897 | Ramirez Morales v. SHHS U.S. District Court of Puerto Rico
1993/05/26 | 92-2026.01A | 92-2026 | Libertarian Party v. Diamond U.S. District Court for the District of Maine
1993/05/26 | 92-2147.01A | 92-2147 | Alvarez Crespo v. Olavarria Rivera U.S. District Court of Puerto Rico
1993/05/26 | 92-2150.01A | 92-2150 | Boyd v. Boston Gas U.S. District Court for the District of Massachusetts
1993/05/26 | 92-2234.01A | 92-2234 | Sullivan v. US Dept. of Justice U.S. District Court for the District of Maine
1993/05/26 | 93-1152.01A | 93-1152 | Glidden v. USA U.S. District Court for the District of Maine
1993/05/27 | 91-1837.01A | 91-1837 | Benefit Management v. Allstate Life Ins U.S. District Court for the District of Maine
1993/05/27 | 92-2230.01A | 92-2230 | Stow v. Grimaldi, et al U.S. District Court for the District of New Hampshire
1993/05/27 | 92-2438.01A | 92-2438 | Baez Velez v. SHHS U.S. District Court of Puerto Rico
1993/05/28 | 92-1613.01A | 92-1613 | US v. Carty U.S. District Court for the District of Rhode Island
1993/05/28 | 92-2134.01A | 92-2134 | O'Connor v. Steevs, Et Al. U.S. District Court for the District of Massachusetts
1993/05/28 | 92-2202.01A | 92-2202 | United States v. Higgins U.S. District Court for the District of Maine
1993/06/01 | 92-2308.01A | 92-2308 | Serrano v. SHHS U.S. District Court of Puerto Rico
1993/06/01 | 92-2320.01A | 92-2320 | Soling v. Brady, et al U.S. District Court for the District of Massachusetts
1993/06/01 | 93-1485.01A | 93-1485 | In Re: Grand Jury v. Doe U.S. District Court for the District of Massachusetts
1993/06/02 | 92-1693.01A | 92-1693 | Southworth v. F
1993/06/03 | 92-1169.01A | 92-1169 | United States v. Brennan U.S. District Court for the District of Massachusetts
1993/06/03 | 92-2408.01A | 92-2408 | In Re: Nelson v. Taglienti U.S. District Court for the District of Massachusetts
1993/06/04 | 92-1775.01A | 92-1775 | Washington Legal v. Massachusetts Bar U.S. District Court for the District of Massachusetts
1993/06/04 | 92-2111.01A | 92-2111 | Perez Velazquez v. SHHS U.S. District Court of Puerto Rico
1993/06/04 | 92-2280.01A | 92-2280 | Tempelman v. USA, et al U.S. District Court for the District of New Hampshire
1993/06/04 | 92-2286.01A | 92-2286 | Martel v. Stafford, Etc. U.S. District Court for the District of Massachusetts
1993/06/04 | 92-2312.01A | 92-2312 | In Re: San Juan v. U.S. District Court of Puerto Rico
1993/06/07 | 92-1165.01A | 92-1165 | Northeast Utils. v. FERC U.S. Tax Court, Washington, D.C.
1993/06/07 | 92-1165.01A | 92-1261 | Vermont Department v. FERC U.S. Tax Court, Washington, D.C.
1993/06/07 | 92-1165.01A | 92-1262 | Massachusetts Muni. v. FERC U.S. Tax Court, Washington, D.C.
1993/06/07 | 92-1165.01A | 92-1263 | Concord, Et Al v. FERC U.S. Tax Court, Washington, D.C.
1993/06/07 | 92-1165.01A | 92-1264 | Central Maine Power v. FERC U.S. Tax Court, Washington, D.C.
1993/06/07 | 92-1165.01A | 92-1316 | City of Holyoke v. FERC U.S. Tax Court, Washington, D.C.
1993/06/07 | 92-1165.01A | 92-1328 | Canal Electric Co., v. FERC U.S. Tax Court, Washington, D.C.
1993/06/08 | 92-1049.01A | 92-1049 | Das v. Ciba U.S. District Court for the District of Massachusetts
1993/06/08 | 92-1982.01A | 92-1982 | US v. Person U.S. District Court for the District of Rhode Island
1993/06/08 | 92-2435.01A | 92-2435 | Santiago-Martinez v. USA U.S. District Court for the District of Rhode Island
1993/06/09 | 92-1715.01A | 92-1715 | Rosa v. Figueroa Gomez,et al U.S. District Court of Puerto Rico
1993/06/09 | 92-1715.01A | 92-2155 | Rosa Velazquez, Et v. Figueroa, Et Al. U.S. District Court of Puerto Rico
1993/06/09 | 92-1715.01A | 92-2222 | Rosa v. Figueroa Gomez,et al U.S. District Court of Puerto Rico
1993/06/09 | 92-1715.01A | 92-2223 | Rosa v. Figueroa Gomez,et al U.S. District Court of Puerto Rico
1993/06/09 | 92-1970.01A | 92-1970 | Santiago-Jimenez v. SHHS U.S. District Court of Puerto Rico
1993/06/09 | 92-2024.01A | 92-2024 | Blanco v. U.S. of America U.S. District Court for the District of Rhode Island
1993/06/09 | 92-2113.01A | 92-2113 | Mount v. Zobel U.S. District Court for the District of Massachusetts
1993/06/09 | 92-2412.01A | 92-2412 | Stow v. State Prison, et al U.S. District Court for the District of New Hampshire
1993/06/10 | 92-1764.01A | 92-1764 | Skidgel v. Maine HHS U.S. District Court for the District of Maine
1993/06/10 | 92-1764.01A | 92-1824 | Skidgel v. Maine HHS & Ives U.S. District Court for the District of Maine
1993/06/10 | 92-2462.01A | 92-2462 | Diekan v. Stone U.S. District Court for the District of Massachusetts
1993/06/10 | 93-1222.01A | 93-1222 | Buco v. USA U.S. District Court for the District of Massachusetts
1993/06/14 | 92-1834.01A | 92-1834 | US v. Kareem Agoro U.S. District Court for the District of Rhode Island
1993/06/14 | 92-2192.01A | 92-2192 | Niemela v. U.S. of America U.S. District Court for the District of Massachusetts
1993/06/14 | 92-2302.01A | 92-2302 | Nunnally v. MacCausland U.S. District Court for the District of Massachusetts
1993/06/14 | 92-2369.01A | 92-2369 | In Re: v. La. Electronica, Inc U.S. District Court of Puerto Rico
1993/06/14 | 92-2421.01A | 92-2421 | Agbosasa v. Cooper, et al U.S. District Court for the District of Rhode Island
1993/06/14 | 92-2423.01A | 92-2423 | Teresa J. Robleto v. Bush-Rodriguez U.S. District Court of Puerto Rico
1993/06/14 | 92-2444.01A | 92-2444 | Bushway DeSouza v. USA U.S. District Court for the District of New Hampshire
1993/06/14 | 93-1038.01A | 93-1038 | Naidich v. Mitre Cor & Horowitz U.S. District Court for the District of Massachusetts
1993/06/14 | 93-1164.01A | 93-1164 | Dempsey v. White U.S. District Court for the District of Massachusetts
1993/06/15 | 92-1546.01A | 92-1546 | U.S v. Moore U.S. District Court for the District of Massachusetts
1993/06/15 | 92-1883.01A | 92-1883 | Ward v. Hickey, Et Al., U.S. District Court for the District of Massachusetts
1993/06/15 | 92-1883.01A | 92-2240 | Ward v. Hickey, Et Al., U.S. District Court for the District of Massachusetts
1993/06/15 | 92-1883.01A | 92-2241 | Ward v. Hickey, Et Al., U.S. District Court for the District of Massachusetts
1993/06/15 | 92-1883.01A | 92-2271 | Ward v. Hickey, Et Al., U.S. District Court for the District of Massachusetts
1993/06/15 | 92-2109.01A | 92-2109 | Santoni Lorenzi v. Woolworth U.S. District Court of Puerto Rico
1993/06/16 | 91-2062A.01A | 91-2062 | Sierra Serpa v. Martinez, Et. Al. U.S. District Court of Puerto Rico
1993/06/16 | 92-2468.01A | 92-2468 | Topp v. Wolkowski U.S. District Court for the District of New Hampshire
1993/06/16 | 93-1223.01A | 93-1223 | Amelung v. Milton Savings Bank U.S. District Court for the District of Massachusetts
1993/06/21 | 91-1290.01A | 91-1290 | United States v. Ortiz Arrigotia U.S. District Court of Puerto Rico
1993/06/21 | 92-2397.01A | 92-2397 | United States v. St. Germaine U.S. District Court for the District of Maine
1993/06/22 | 92-1424.01A | 92-1424 | US v. Ricciardelli U.S. District Court for the District of Massachusetts
1993/06/23 | 92-2108.01A | 92-2108 | USA v. American Heart U.S. District Court for the District of New Hampshire
1993/06/23 | 92-2389.01A | 92-2389 | Broderick v. Roache U.S. District Court for the District of Massachusetts
1993/06/23 | 93-1519.01A | 93-1519 | Fischer v. Rollins U.S. District Court for the District of Massachusetts
1993/06/24 | 92-1279.01A | 92-1279 | United States v. De La Cruz U.S. District Court for the District of Massachusetts
1993/06/24 | 92-1651.01A | 92-1651 | Municipality v. Banco U.S. District Court of Puerto Rico
1993/06/24 | 92-1651.01A | 92-1652 | Municipality v. Prudential U.S. District Court of Puerto Rico
1993/06/24 | 92-1749.01A | 92-1749 | US v. Mirna Rivera U.S. District Court for the District of Rhode Island
1993/06/24 | 93-1113.01A | 93-1113 | King v. Martin Feed Mills U.S. District Court for the District of Massachusetts
1993/06/24 | 93-1253.01A | 93-1253 | Griffin v. Schneider U.S. District Court for the District of Maine